pub struct FunctionScoreQuery<S = Root> { /* private fields */ }Expand description
Implementations
Sourceimpl<S> FunctionScoreQuery<S>
impl<S> FunctionScoreQuery<S>
Sourcepub fn weight(self, weight: f32) -> Self
pub fn weight(self, weight: f32) -> Self
Add a constant weight function applied to every match.
Sourcepub fn weight_when(self, weight: f32, filter: impl AsQuery<S>) -> Self
pub fn weight_when(self, weight: f32, filter: impl AsQuery<S>) -> Self
Add a constant weight function applied only to matches of filter.
Sourcepub fn function(self, function: Value) -> Self
pub fn function(self, function: Value) -> Self
Add a raw function entry (e.g. a field_value_factor, gauss, or
script_score object) — the escape hatch for the long tail of function
types, still composed into the typed clause.
Sourcepub fn score_mode(self, score_mode: ScoreMode) -> Self
pub fn score_mode(self, score_mode: ScoreMode) -> Self
How the functions combine (ScoreMode::Multiply is the default).
Sourcepub fn boost_mode(self, boost_mode: BoostMode) -> Self
pub fn boost_mode(self, boost_mode: BoostMode) -> Self
How the function score combines with the query score
(BoostMode::Multiply is the default).