pub struct MoreLikeThisQuery<S = Root> { /* private fields */ }Expand description
A more_like_this clause.
Implementations
Sourceimpl<S> MoreLikeThisQuery<S>
impl<S> MoreLikeThisQuery<S>
Sourcepub fn min_term_freq(self, min_term_freq: u32) -> Self
pub fn min_term_freq(self, min_term_freq: u32) -> Self
Ignore source terms occurring fewer than this many times.
Sourcepub fn max_query_terms(self, max_query_terms: u32) -> Self
pub fn max_query_terms(self, max_query_terms: u32) -> Self
Cap on the terms selected from the source text.
Sourcepub fn minimum_should_match(self, value: impl Into<MinimumShouldMatch>) -> Self
pub fn minimum_should_match(self, value: impl Into<MinimumShouldMatch>) -> Self
How many selected terms must match (e.g. MinimumShouldMatch::percent(30)).