AsQuery

Trait AsQuery 

pub trait AsQuery<S> {
    // Required method
    fn into_query(self) -> Option<Query<S>>;
}
Anything that can become a query clause in scope S. A clause may be absent (into_query returns None) — that’s what makes an Option<Query<S>> a first-class optional filter.

Required Methods

fn into_query(self) -> Option<Query<S>>

The clause this produces, or None to contribute nothing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S, T: AsQuery<S>> AsQuery<S> for Option<T>

Implementors

Source

impl<S> AsQuery<S> for Query<S>